package netscape.plugin.composer.io;

import java.util.Enumeration;
import java.util.Hashtable;

public class Tag extends Token {
   private String name;
   private boolean open;
   private Hashtable attributes;
   private static String emptyString = "";

   public Tag(String var1) {
      this(var1, true);
   }

   public Tag(String var1, boolean var2) {
      this.name = var1.toUpperCase();
      this.open = var2;
   }

   public Object clone() {
      Tag var1 = null;

      try {
         var1 = (Tag)super.clone();
      } catch (CloneNotSupportedException var3) {
         ((Throwable)var3).printStackTrace();
      }

      if (var1.attributes != null) {
         var1.attributes = (Hashtable)var1.attributes.clone();
      }

      return var1;
   }

   public String getName() {
      return this.name;
   }

   public boolean isOpen() {
      return this.open;
   }

   public boolean isClose() {
      return !this.open;
   }

   public void clearAttributes() {
      if (this.attributes != null) {
         this.attributes.clear();
      }

   }

   public String addAttribute(String var1, String var2) {
      var1 = var1.toUpperCase();
      if (this.attributes == null) {
         this.attributes = new Hashtable(7);
      }

      if (var2 == null || var2.length() == 0) {
         var2 = emptyString;
      }

      return (String)this.attributes.put(var1, var2);
   }

   public String removeAttribute(String var1) {
      return this.attributes == null ? null : (String)this.attributes.remove(var1);
   }

   public String lookupAttribute(String var1) {
      return this.attributes == null ? null : (String)this.attributes.get(var1);
   }

   public boolean containsAttribute(String var1) {
      if (this.attributes == null) {
         return false;
      } else {
         return this.attributes.get(var1) != null;
      }
   }

   public Enumeration getAttributes() {
      if (this.attributes == null) {
         this.attributes = new Hashtable();
      }

      return this.attributes.keys();
   }

   public boolean hasAttributes() {
      if (this.attributes == null) {
         return false;
      } else {
         return !this.attributes.isEmpty();
      }
   }

   public String toString() {
      FooStringBuffer var1 = new FooStringBuffer();
      var1.append('<');
      if (!this.open) {
         var1.append('/');
      }

      var1.append(this.name.toString());
      if (this.attributes != null) {
         Enumeration var2 = this.attributes.keys();

         while(var2.hasMoreElements()) {
            String var3 = (String)var2.nextElement();
            var1.append(' ');
            var1.append(var3.toString());
            String var4 = (String)this.attributes.get(var3);
            if (var4 != emptyString) {
               var1.append('=');
               var1.append(QuoteValue(var4));
            }
         }
      }

      var1.append('>');
      return var1.toString();
   }

   public int hashCode() {
      int var1 = this.name.hashCode() + (this.open ? 1 : 0);
      String var3;
      String var4;
      if (this.attributes != null) {
         for(Enumeration var2 = this.attributes.keys(); var2.hasMoreElements(); var1 = var1 ^ var3.hashCode() << 3 ^ var4.hashCode() << 13) {
            var3 = (String)var2.nextElement();
            var4 = (String)this.attributes.get(var3);
         }
      }

      return var1;
   }

   public boolean equals(Object var1) {
      if (var1 != null && var1 instanceof Tag) {
         Tag var2 = (Tag)var1;
         if (!this.name.equals(var2.name)) {
            return false;
         } else if ((this.attributes == null || var2.attributes != null) && (this.attributes != null || var2.attributes == null)) {
            if (this.attributes == null) {
               return true;
            } else if (this.attributes.size() != var2.attributes.size()) {
               return false;
            } else {
               Enumeration var3 = this.attributes.keys();

               while(var3.hasMoreElements()) {
                  String var4 = (String)var3.nextElement();
                  String var5 = (String)this.attributes.get(var4);
                  String var6 = (String)var2.attributes.get(var4);
                  if (var5 != null) {
                     if (!var5.equals(var6)) {
                        return false;
                     }
                  } else if (var6 != null) {
                     return false;
                  }
               }

               return true;
            }
         } else {
            return false;
         }
      } else {
         return false;
      }
   }

   private static String QuoteValue(String var0) {
      return "\"" + var0 + "\"";
   }
}
